@@ -268,9 +268,7 @@ class KeywordSyntax(Syntax):
     def validate_rulelike_syntax(self, snakefile: TokenIterator):
         if not is_colon(self.token):
             if self.token.type != tokenize.NAME:
-                raise NotAnIdentifierError(
-                    self.line_nb, self.token.string, self.keyword_line
-                )
+                NotAnIdentifierError(self.line_nb, self.token.string, self.keyword_line)
             self.keyword_line += f" {self.token.string}"
             self.token = next(snakefile)
         if not is_colon(self.token):
@@ -396,6 +394,12 @@ class ParameterSyntax(Syntax):
         return cur_param
 
     def flush_param(self, parameter: Parameter, skip_empty: bool = False) -> None:
+        if parameter.has_a_key() and not parameter.has_value():
+            raise NoParametersError(
+                f"{self.line_nb}In {self.keyword_name} definition, "
+                f"keyword {parameter.key}"
+            )
+
         if not parameter.has_value() and skip_empty:
             return
 
